# NoTest Framework

NoTest是一个Python集成测试框架，使用了yaml/json格式来定义测试场景和配置，支持插件式结果解析和验证方式。


[Core Concepts](docs/core_concepts.md#concepts)

[Installation Spec](docs/installation.md#installation)

[Quick Start](docs/quick_start.md#quick-start)

[API Test Demo App](docs/api_test_demo_app.md#test-app-demo)

[Basic Features](docs/basic_features.md#basic-features)

[Advanced Features](docs/advanced_features.md#advanced-features)

[Plugin Development](docs/plugin_dev.md#plugin-development)

[Testcase Generator](docs/testcase_generator.md#Description)


NoTest最初版本始于[PyRestTest](https://github.com/svanoort/pyresttest)，由于pyresttest最后更新是2015年，功能已年久失修且与主流python版本不兼容，notest在保留优秀特性的基础上增加了python3.5+的支持，并进行了大量重构和扩展。

